@@ -5,14 +5,16 @@ import subprocess
 import sys
 from distutils.sysconfig import get_python_lib
 
+# from PyInquirer import prompt
+import PyInquirer
 import click
-import daemon.daemon
+import daemon.daemon as ppd
 import psutil
-from PyInquirer import prompt
 
 from prtg_pyprobe.run import main as pyprobe_main
-from prtg_pyprobe.utils.config import configuration_questions, ProbeConfig
-from prtg_pyprobe.utils.defaults import CONFIG_PATH, LOG_PATH
+from prtg_pyprobe.utils import config
+from prtg_pyprobe.utils.config import configuration_questions
+from prtg_pyprobe.utils.defaults import LOG_PATH, CONFIG_PATH
 
 
 def hash_access_key(key):
@@ -38,7 +40,7 @@ def dstart():
     site_packages = get_python_lib()
     work_dir = f"{site_packages}/prtg_pyprobe/"
     click.echo("pyprobe daemon starting")
-    with daemon.DaemonContext(
+    with ppd.DaemonContext(
         working_directory=work_dir,
     ):
         pyprobe_main()
@@ -80,7 +82,7 @@ def configure():
         config_name = "config.yml"
         if os.path.isfile(f"{CONFIG_PATH}{config_name}"):
             click.echo("\033[93m Completing this config wizard will overwrite your current config! \033[93m")
-            cont = prompt(
+            cont = PyInquirer.prompt(
                 {
                     "type": "confirm",
                     "message": "Do you want to continue?",
@@ -90,14 +92,14 @@ def configure():
             )
             if not cont["continue"]:
                 raise KeyboardInterrupt
-        answers = prompt(configuration_questions)
+        answers = PyInquirer.prompt(configuration_questions)
     except KeyboardInterrupt:
         print("Exiting configuration wizard")
         sys.exit(0)
     if answers != {}:
         answers["probe_protocol_version"] = "1"
         answers["probe_access_key_hashed"] = hash_access_key(answers["probe_access_key"])
-        probe_cfg = ProbeConfig(path=f"{CONFIG_PATH}{config_name}")
+        probe_cfg = config.ProbeConfig(path=f"{CONFIG_PATH}{config_name}")
         probe_cfg.write(answers)
         click.echo(f"Config written to {CONFIG_PATH}{config_name}")
 
